icsemantic.catalog.tests.test_setup

Package platecom :: Package ontocatalog :: Package tests :: Module test_setup |
[hide private]
[frames] | no frames]

# Source Code for Module icsemantic.catalog.tests.test_setup

     1  """Test OntoCatalog setup on installation.
     2  """
     3
     4  import unittest
     5
     6  from platecom.utils.interfaces import IicSemanticManagementAdvancedSearchOptions
     7  from platecom.ontocatalog.tests.base import OntoCatalogTestCase
     8
     9
    10 -class TestOntoCatalogSetup(OntoCatalogTestCase):
    11      """Testing the product setup"""
    12
    13 -    def test_langview_installed(self):
    14          """Test that plantecom.langview is installed as a dependency"""
    15          pass
    16
    17 -    def test_pluggablecatalog_installed(self):
    18          """Test that pluggablecatalog is installed as a dependency"""
    19          pass
    20
    21 -    def test_linguaplone_installed(self):
    22          """Test that LinguaPlone is installed as a dependency"""
    23          pass
    24
    25 -    def test_ontoplone_installed(self):
    26          """Test that icsemantic.thesaurus is installed as a dependency"""
    27          pass
    28
    29 -    def test_synonym_index_added(self):
    30          """Test that a new SynonymIndex was added to the catalog"""
    31          pass
    32
    33 -    def test_related_index_added(self):
    34          """Test that a new RelatedIndex was added to the catalog"""
    35          pass
    36
    37 -    def test_translation_index_added(self):
    38          """Test that a new TranslationIndex was added to the catalog"""
    39          pass
    40
    41 -    def test_advanced_search(self):
    42          """Test that the criteria from OntoCatalog are turned off from
    43          the default search by default.
    44          """
    45          sm = self.portal.getSiteManager()
    46          pmas = sm.queryUtility(IicSemanticManagementAdvancedSearchOptions,
    47                                 name='platecom.advancedsearch')
    48          self.failIf(pmas.include_ontocatalog_criteria)
    49
    50 -    def test_ontocatalog_criteria_available_in_topics(self):
    51          """Test that the OntoCatalog criteria are available to use in
    52          ATTopics.
    53          """
    54          pass
    55
    56 -    def test_catalog_replaced(self):
    57          """Test that the default values for a catalog search were
    58          replaced.
    59          """
    60          pass
    61
    62
    63 -def test_suite():
    64      suite = unittest.TestSuite()
    65      suite.addTest(unittest.makeSuite(TestOntoCatalogSetup))
    66      return suite
    67